==> qcad-3.15.5.3.tgz: lib/qcad/scripts/File/SaveAs/ts/SaveAs_sk.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="sk">
<context>
    <name>SaveAs</name>
    <message>
        <location filename="../PreferencesPage.ui" line="+17"/>
        <source>File Dialog</source>
        <translation>Dialógové okno súboru</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Use system file dialog</source>
        <translation>Použiť systémové súborové okno</translation>
    </message>
    <message>
        <location line="+13"/>
        <source>Saving</source>
        <translation>Uložiť</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Default format:</source>
        <translation>Štandardný formát:</translation>
    </message>
    <message>
        <location line="+37"/>
        <source>Show warning when saving to a file format that does not support 24bit colors</source>
        <translation>Zobraziť varovanie pri ukladaní súboru do formátu, ktorý nepodporuje 24 bitové farby</translation>
    </message>
    <message>
        <location filename="../SaveAs.js" line="+38"/>
        <source>Load/Save</source>
        <translation>Načítať/Uložiť</translation>
    </message>
    <message>
        <source>Save as</source>
        <translation type="vanished">Uložiť ako</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>File</source>
        <translation>Súbor</translation>
    </message>
    <message>
        <location line="+24"/>
        <source>No export filters have been found. Aborting...</source>
        <translation>Žiadne exportné filtre sa nenašli. Ukončujem...</translation>
    </message>
    <message>
        <location line="+65"/>
        <source>Format:</source>
        <translation>Formát:</translation>
    </message>
    <message>
        <location filename="../SaveAsInit.js" line="+2"/>
        <source>Save &amp;As...</source>
        <translation>Uložiť &amp;ako...</translation>
    </message>
</context>
</TS>

==> qcad-3.21.2.3.tgz: lib/qcad/scripts/File/SaveAs/ts/SaveAs_sk.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="sk">
<context>
    <name>SaveAs</name>
    <message>
        <location filename="../PreferencesPage.ui" line="+17"/>
        <source>File Dialog</source>
        <translation>Dialógové okno súboru</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Use system file dialog</source>
        <translation>Použiť systémové súborové okno</translation>
    </message>
    <message>
        <location line="+13"/>
        <source>Saving</source>
        <translation>Uložiť</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Default format:</source>
        <translation>Štandardný formát:</translation>
    </message>
    <message>
        <location line="+37"/>
        <source>Show warning when saving to a file format that does not support 24bit colors</source>
        <translation>Zobraziť varovanie pri ukladaní súboru do formátu, ktorý nepodporuje 24 bitové farby</translation>
    </message>
    <message>
        <source>Load/Save</source>
        <translation type="vanished">Načítať/Uložiť</translation>
    </message>
    <message>
        <source>Save as</source>
        <translation type="vanished">Uložiť ako</translation>
    </message>
    <message>
        <location filename="../SaveAs.js" line="+38"/>
        <source>File</source>
        <translation>Súbor</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Open/Save</source>
        <translation>Otvoriť/Uložiť</translation>
    </message>
    <message>
        <location line="+25"/>
        <source>No export filters have been found. Aborting...</source>
        <translation>Žiadne exportné filtre sa nenašli. Ukončujem...</translation>
    </message>
    <message>
        <location line="+74"/>
        <source>Format:</source>
        <translation>Formát:</translation>
    </message>
    <message>
        <location filename="../SaveAsInit.js" line="+2"/>
        <source>Save &amp;As...</source>
        <translation>Uložiť &amp;ako...</translation>
    </message>
</context>
</TS>
